==> parsermd_0.1.0.tar.gz: parsermd/tests/testthat/_snaps/print_tree.md <==
# tree printing

    +-- YAML [4 lines]
    +-- Heading [h1] - Setup
    |   \-- Chunk [r, 1 opt, 1 lines] - setup
    \-- Heading [h1] - Content
        +-- Heading [h2] - R Markdown
        |   +-- Markdown [6 lines]
        |   +-- Chunk [r, 1 lines] - cars
        |   \-- Chunk [r, 1 lines] - <unnamed>
        \-- Heading [h2] - Including Plots
            +-- Markdown [2 lines]
            +-- Chunk [r, 1 opt, 1 lines] - pressure
            \-- Markdown [2 lines]

---

    +-- YAML [2 lines]
    +-- Heading [h3] - Load packages
    |   \-- Chunk [r, 1 opt, 2 lines] - load-packages
    +-- Heading [h3] - Exercise 1
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       \-- Markdown [5 lines]
    +-- Heading [h3] - Exercise 2
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       +-- Markdown [2 lines]
    |       +-- Chunk [r, 2 opts, 5 lines] - plot-dino
    |       +-- Markdown [2 lines]
    |       \-- Chunk [r, 2 lines] - cor-dino
    \-- Heading [h3] - Exercise 3
        +-- Markdown [2 lines]
        \-- Heading [h4] - Solution
            +-- Chunk [r, 2 opts, 5 lines] - plot-star
            \-- Chunk [r, 2 lines] - cor-star

---

    +-- YAML [2 lines]
    +-- Heading [h3] - Load packages
    |   \-- Chunk [r, 1 opt, 2 lines] - load-packages
    +-- Heading [h3] - Exercise 1
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       \-- Markdown [2 lines]
    +-- Heading [h3] - Exercise 2
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       +-- Markdown [4 lines]
    |       +-- Chunk [r, 2 opts, 5 lines] - plot-dino
    |       +-- Markdown [2 lines]
    |       \-- Chunk [r, 2 lines] - cor-dino
    \-- Heading [h3] - Exercise 3
        +-- Markdown [2 lines]
        \-- Heading [h4] - Solution
            +-- Markdown [4 lines]
            +-- Chunk [r, 1 lines] - plot-star
            +-- Markdown [2 lines]
            \-- Chunk [r, 1 lines] - cor-star

---

    +-- YAML [2 lines]
    +-- Heading [h3] - H3
    +-- Heading [h2] - H2
    |   \-- Heading [h3] - H3 - Part 2
    \-- Heading [h1] - H1

---

    +-- YAML [1 lines]
    +-- Heading [h2] - R Markdown
    |   +-- Markdown [4 lines]
    |   \-- Chunk [r, 1 lines] - cars
    \-- Heading [h2] - Pandoc Raw Attribute Chunk
        +-- Markdown [2 lines]
        \-- Raw Attr Chunk [html, 5 lines]

==> parsermd_0.1.3.tar.gz: parsermd/tests/testthat/_snaps/print_tree.md <==
# tree printing

    +-- YAML [4 lines]
    +-- Heading [h1] - Setup
    |   \-- Chunk [r, 1 opt, 1 lines] - setup
    \-- Heading [h1] - Content
        +-- Heading [h2] - R Markdown
        |   +-- Markdown [6 lines]
        |   +-- Chunk [r, 1 lines] - cars
        |   \-- Chunk [r, 1 lines] - unnamed-chunk-1
        \-- Heading [h2] - Including Plots
            +-- Markdown [2 lines]
            +-- Chunk [r, 1 opt, 1 lines] - pressure
            \-- Markdown [2 lines]

---

    +-- YAML [2 lines]
    +-- Heading [h3] - Load packages
    |   \-- Chunk [r, 1 opt, 2 lines] - load-packages
    +-- Heading [h3] - Exercise 1
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       \-- Markdown [5 lines]
    +-- Heading [h3] - Exercise 2
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       +-- Markdown [2 lines]
    |       +-- Chunk [r, 2 opts, 5 lines] - plot-dino
    |       +-- Markdown [2 lines]
    |       \-- Chunk [r, 2 lines] - cor-dino
    \-- Heading [h3] - Exercise 3
        +-- Markdown [2 lines]
        \-- Heading [h4] - Solution
            +-- Chunk [r, 2 opts, 5 lines] - plot-star
            \-- Chunk [r, 2 lines] - cor-star

---

    +-- YAML [2 lines]
    +-- Heading [h3] - Load packages
    |   \-- Chunk [r, 1 opt, 2 lines] - load-packages
    +-- Heading [h3] - Exercise 1
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       \-- Markdown [2 lines]
    +-- Heading [h3] - Exercise 2
    |   +-- Markdown [2 lines]
    |   \-- Heading [h4] - Solution
    |       +-- Markdown [4 lines]
    |       +-- Chunk [r, 2 opts, 5 lines] - plot-dino
    |       +-- Markdown [2 lines]
    |       \-- Chunk [r, 2 lines] - cor-dino
    \-- Heading [h3] - Exercise 3
        +-- Markdown [2 lines]
        \-- Heading [h4] - Solution
            +-- Markdown [4 lines]
            +-- Chunk [r, 1 lines] - plot-star
            +-- Markdown [2 lines]
            \-- Chunk [r, 1 lines] - cor-star

---

    +-- YAML [2 lines]
    +-- Heading [h3] - H3
    +-- Heading [h2] - H2
    |   \-- Heading [h3] - H3 - Part 2
    \-- Heading [h1] - H1

---

    +-- YAML [1 lines]
    +-- Heading [h2] - R Markdown
    |   +-- Markdown [4 lines]
    |   \-- Chunk [r, 1 lines] - cars
    \-- Heading [h2] - Pandoc Raw Attribute Chunk
        +-- Markdown [2 lines]
        \-- Raw Attr Chunk [html, 5 lines]
